@@ -40,6 +40,8 @@ def _batch_records_helper(
     max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
     min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
 ) -> Tuple[Batch, list]:
+    max_batch_size = max_batch_size if not max_batch_size == None else DEFAULT_MAX_BATCH_SIZE
+    min_common_dimensions = min_common_dimensions if not min_common_dimensions == None else DEFAULT_MIN_COMMON_DIMENSIONS
     DEFAULT_LOGGER.info(f"HELPER MAX BATCH || {max_batch_size}  MIN COMMON DIM || {min_common_dimensions}")
     
     assert max_batch_size > 0 and max_batch_size <= DEFAULT_MAX_BATCH_SIZE
