@@ -3,6 +3,7 @@ import pytz
 
 from datetime import datetime
 from timestream.dimensions import TimestreamDimensions
+from timestream.util import is_time_key, is_version_key
 
 
 class TimestreamRecord:
@@ -21,6 +22,8 @@ class TimestreamRecord:
         mstime: int = None
     ):
         assert measure_name and type(measure_name) is str, f'Invalid measure name "{measure_name}" with type "{type(measure_name)}"'
+        assert not is_time_key(measure_name), f'Invalid measure name "{measure_name}". Keyword "time" cannot be used as a measure name'
+        assert not is_version_key(measure_name), f'Invalid measure name "{measure_name}". Keyword "version" cannot be used as a measure name'
         assert type(measure_value) in [int, float], f'Invalid measure value type "{type(measure_value)}"'
         assert not dimensions or type(dimensions) is TimestreamDimensions, f'Invalid dimensions for TimestreamRecord with type {type(dimensions)}'
         assert not mstime or (type(mstime) is int and mstime > 0), f'Millisecond time must be an integer greater than 0, got {mstime}'
