@@ -26,7 +26,15 @@ class TimestreamLoader(TimestreamReader):
         super().__init__(session, current_time_ms, logger)
         self.__database_name = database_name
         self.__table_name = table_name
-        
+
+    @property
+    def database_name(self) -> str:
+        return self.__database_name
+
+    @property
+    def table_name(self) -> str:
+        return self.__table_name
+
     def does_database_exist(
         self,
         database_name: str = None,
